@@ -7,10 +7,17 @@ this->setText(QString("%1").arg(event->nativeScanCode()));
 event->ignore();
 }
 
-keys::keys(QWidget *parent) :
-    QDialog(parent)
+sh_key::sh_key(QWidget *parent) :
+        QLineEdit(parent)
 {
+    this->setAlignment(Qt::AlignCenter);
+}
 
+keys::keys(QWidget *parent) :
+        QWidget(parent)
+{
+this->setWindowFlags(this->windowFlags() | Qt::Window);
+this->setAttribute(Qt::WA_Maemo5StackedWindow);
 QScrollArea *area=new QScrollArea(this);
 QVBoxLayout *lay=new QVBoxLayout(this);
 lay->addWidget(area);
@@ -26,15 +33,12 @@ grid->setVerticalSpacing(25);
 QStringList ks=QStringList()<<tr("Left")<<tr("Right")<<tr("Up")
                             <<tr("Down")<<tr("o")<<tr("x")<<tr("triangle")
                             <<tr("square")<<tr("Select")<<tr("Start")
-                            <<tr("L2")<<tr("R2")<<tr("L1")<<tr("R2")<<tr("Quit")
+                            <<tr("L1")<<tr("R1")<<tr("L2")<<tr("R2")<<tr("Quit")
                             <<tr("Up+Left")<<tr("Up+Right")
                             <<tr("Down+Left")<<tr("Down+Right")
                             <<tr("Save")<<tr("Load");
 
 
-grid->setColumnStretch(1, 10);
-grid->setColumnStretch(2, 20);
-
 // load current
 
 QFile file("/opt/psx4m/keys");
@@ -54,7 +58,7 @@ int o=0;
          QLabel *lbl=new QLabel(ks.at(o),wg);
          grid->addWidget(lbl,o,1,1,1);
 
-         nkey[o]=new sh_key();
+         nkey[o]=new sh_key(wg);
          nkey[o]->setParent(wg);
          nkey[o]->setMinimumSize(150,60);
 
@@ -65,19 +69,28 @@ int o=0;
          o++;
      }
 
-
-     QPushButton *but=new QPushButton(tr("Save"),this);
-     grid->addWidget(but,21,0,2,2);
-     connect(but,SIGNAL(clicked()),this,SLOT(save()));
-
+}
+void keys::hideEvent(QHideEvent *){
+    if (!this->isVisible()){
+        QDialog *dlg=new QDialog(this);
+        QGridLayout *lay=new QGridLayout(dlg);
+        QLabel *lbl=new QLabel(tr("Do you want to save settings?"),dlg);
+        lay->addWidget(lbl,1,0,1,2);
+        QPushButton *yes=new QPushButton(tr("Yes"),dlg);
+        QPushButton *no=new QPushButton(tr("No"),dlg);
+        connect (yes,SIGNAL(clicked()),dlg,SLOT(accept()));
+        connect (no,SIGNAL(clicked()),dlg,SLOT(reject()));
+        connect (dlg,SIGNAL(accepted()),this,SLOT(save()));
+        lay->addWidget(yes,2,0);
+        lay->addWidget(no ,2,1);
+        dlg->exec();
+    }
 }
 
 void keys::save(){
 QString sv="";
-qDebug("1");
 for (int i=0;i<=20;i++)
     sv=sv+QString("%1\n").arg(nkey[i]->text());
-qDebug("2");
 
 QFile file("/opt/psx4m/keys");
 if (!file.open(QIODevice::WriteOnly | QIODevice::Text)){
@@ -88,15 +101,6 @@ if (!file.open(QIODevice::WriteOnly | QIODevice::Text)){
 
      QTextStream out(&file);
      out <<sv;
-qDebug("3");
-this->accept();
-this->close();
-}
-
-void keys::hk(QString txt){
-    QLineEdit *action = qobject_cast<QLineEdit *>(sender());
-    action->setText(QString("%1").arg((int)QChar(txt.at(0)).toAscii() ));
-    action->setCursorPosition(0);
 
 }
 
