@@ -12,13 +12,16 @@ class sh_key : public QLineEdit
 {
     Q_OBJECT
 
+public:
+    explicit sh_key(QWidget *parent = 0);
+
 protected:
 void keyPressEvent ( QKeyEvent * event ) ;
 
 };
 
 
-class keys : public QDialog
+class keys : public QWidget
 {
     Q_OBJECT
 
@@ -28,8 +31,9 @@ public:
 private:
     sh_key *nkey[21];
 private slots:
-    void hk(QString);
     void save();
+protected:
+    void hideEvent(QHideEvent *);
 
 };
 
